@@ -6,12 +6,14 @@ from .base import AvakasLegacy
 from .ansible import AvakasAnsibleProject
 from .chef import AvakasChefProject
 from .erlang import AvakasErlangProject
+from .git import AvakasGitNative
 from .node import AvakasNodeProject
 
 __all__ = [
-    'AvakasLegacy',
     'AvakasAnsibleProject',
     'AvakasChefProject',
     'AvakasErlangProject',
+    'AvakasGitNative',
+    'AvakasLegacy',
     'AvakasNodeProject',
 ]
