@@ -7,6 +7,7 @@ import sys
 import os
 from functools import cmp_to_key
 import contextlib
+from pkg_resources import resource_string, resource_filename
 
 from semantic_version import compare
 
@@ -47,3 +48,14 @@ def sort_versions(versions):
     Sort a list of version strings by semantic version
     """
     return sorted(versions, key=cmp_to_key(compare))
+
+
+def my_version():
+    """
+    Returns the current version of avakas itself.
+    """
+    if os.path.exists(resource_filename(__name__, 'version')):
+        return resource_string(__name__, 'version')
+
+    return open(os.path.join(os.path.dirname(__file__),
+                             "..", "version")).read()
